@@ -142,7 +142,7 @@ class Package2Pod(object):
                     method = getattr(Wrappers, wrapper)
                     if method:
                         Wrappers.current_field_map = field_map
-                        dataset[key] = method(dataset.get(key))
+                        dataset[key] = method(dataset.get(key, ""))
 
             # CKAN doesn't like empty values on harvest, let's get rid of them
             # Remove entries where value is None, "", or empty list []
@@ -473,9 +473,11 @@ class Wrappers(object):
         if not value:
             return value
         formats = h.resource_formats()
+        formats.update(helpers.get_additional_formats())
         format_clean = value.lower()
         if format_clean in formats:
             mime_type = formats[format_clean][0]
+            mime_type = mime_type if mime_type else 'application/octet-stream'
         else:
             mime_type = value
         msg = value + ' ... BECOMES ... ' + mime_type
